summaryrefslogtreecommitdiffstats
path: root/khangman
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:27 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:27 -0600
commit9f2c757e1a1694373c11427a00502c2ff4c2d403 (patch)
tree7d90e91214976a7d23d89ec3474515cf46069704 /khangman
parentcee429821aa6f1acc97fb482d325fb4eb37376ca (diff)
downloadtdeedu-9f2c757e1a1694373c11427a00502c2ff4c2d403.tar.gz
tdeedu-9f2c757e1a1694373c11427a00502c2ff4c2d403.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'khangman')
-rw-r--r--khangman/khangman/fontchecker.cpp2
-rw-r--r--khangman/khangman/khangman.cpp10
-rw-r--r--khangman/khangman/khangman.kcfg2
3 files changed, 7 insertions, 7 deletions
diff --git a/khangman/khangman/fontchecker.cpp b/khangman/khangman/fontchecker.cpp
index 55e18601..f6bc9440 100644
--- a/khangman/khangman/fontchecker.cpp
+++ b/khangman/khangman/fontchecker.cpp
@@ -20,7 +20,7 @@ bool fontChecker::checkInstalled(const TQFont &font, const TQString &fontPath)
// Works with Steve may need some tweaking to work with other fonts
if (!fi.exactMatch())
{
- bool success = KIO::NetAccess::copy(fontPath, "fonts:/Personal/", 0);
+ bool success = TDEIO::NetAccess::copy(fontPath, "fonts:/Personal/", 0);
return !success;
}
return true;
diff --git a/khangman/khangman/khangman.kcfg b/khangman/khangman/khangman.kcfg
index 40fa12cb..ff16a334 100644
--- a/khangman/khangman/khangman.kcfg
+++ b/khangman/khangman/khangman.kcfg
@@ -20,7 +20,7 @@
<entry name="SelectedLanguage" type="String">
<label>The language selected by the user</label>
<code>
- KConfigBase *globalConf = TDEGlobal::config();
+ TDEConfigBase *globalConf = TDEGlobal::config();
globalConf->setGroup("Locale");
QString userLanguage = globalConf->readEntry("Language", "en");
if (userLanguage.isEmpty())
diff --git a/khangman/khangman/khangman.cpp b/khangman/khangman/khangman.cpp
index 7113f879..c57565b9 100644
--- a/khangman/khangman/khangman.cpp
+++ b/khangman/khangman/khangman.cpp
@@ -223,7 +223,7 @@ void KHangMan::setLanguages()
temp_languages.clear();
// Write the present languages in config so they cannot be downloaded.
- KConfig *config=kapp->config();
+ TDEConfig *config=kapp->config();
config->setGroup("KNewStuffStatus");
for (uint i=0; i<m_languages.count(); i++) {
TQString tmp = m_languages[i];
@@ -234,7 +234,7 @@ void KHangMan::setLanguages()
// We look in $TDEDIR/share/locale/all_languages from
// tdelibs/tdecore/all_languages to find the name of the country
// corresponding to the code and the language the user set.
- KConfig entry(locate("locale", "all_languages"));
+ TDEConfig entry(locate("locale", "all_languages"));
const TQStringList::ConstIterator itEnd = m_languages.end();
for (TQStringList::Iterator it = m_languages.begin();
it != m_languages.end(); ++it) {
@@ -358,14 +358,14 @@ void KHangMan::loadLevels()
void KHangMan::optionsPreferences()
{
- if ( KConfigDialog::showDialog( "settings" ) ) {
+ if ( TDEConfigDialog::showDialog( "settings" ) ) {
mAdvanced->kcfg_Hint->setEnabled(m_view->hintExists());
mAdvanced->kcfg_AccentedLetters->setEnabled(m_view->accentedLetters());
return;
}
- //KConfigDialog didn't find an instance of this dialog, so lets create it :
- KConfigDialog* dialog = new KConfigDialog( this, "settings", Prefs::self() );
+ //TDEConfigDialog didn't find an instance of this dialog, so lets create it :
+ TDEConfigDialog* dialog = new TDEConfigDialog( this, "settings", Prefs::self() );
// Add the Normal Settings page
normal *mNormal = new normal( 0, "Normal Settings" );
dialog->addPage(mNormal, i18n("General"), "colorize");